# Organizations

ID | Name | API Enabled | Cloud Region Name | Licensing Model | Management Details | URL
--- | --- | --- | --- | --- | --- | ---
739153288842183504 | R4-Sam | True | Asia | co-term | [] | URL
739153288842184109 | Devnet-GroupAlpha | True | Asia | co-term | [] | URL
739153288842183396 | KFC | True | Asia | per-device | [] | URL
739153288842183894 | Bakwas | True | Asia | co-term | [] | URL
739153288842183620 | Foresightbob | True | Asia | co-term | [] | URL
739153288842183262 | Timisoara | True | Asia | co-term | [] | URL
739153288842183354 | Testing123 | True | Asia | co-term | [] | URL
739153288842184112 | Devnet-GroupBeta | True | Asia | co-term | [] | URL
739153288842183257 | Meraki_K | True | Asia | per-device | [] | URL
739153288842184307 | DaisyLeeTest | False | Asia | co-term | [] | URL
739153288842184111 | Devnet-GroupBeta | True | Asia | co-term | [] | URL
739153288842184574 | Artemis Organization | True | Asia | co-term | [] | URL
739153288842184577 | Artemis Organization | True | Asia | co-term | [] | URL
739153288842183778 | ducTran | False | Asia | co-term | [] | URL
739153288842183333 | DevNet Sandbox2 | True | Asia | per-device | [] | URL
646829496481090633 | PNCE Sandbox 01 | True | North America | co-term | [] | URL
959854 | Devnet-VM | True | Asia | per-device | [] | URL
739153288842184115 | Diego-Test2 | True | Asia | co-term | [] | URL
739153288842183647 | MB-Sandbox | True | Asia | co-term | [] | URL
739153288842183516 | Test_ked | True | Asia | co-term | [] | URL
739153288842183661 | NB | True | Asia | co-term | [] | URL
739153288842184136 | Lab_ECMS_PREP | True | Asia | co-term | [] | URL
739153288842183388 | NTT LAB (US) | True | Asia | co-term | [] | URL
739153288842184121 | Devnet-GroupGamma2 | True | Asia | co-term | [] | URL
739153288842183615 | NorbertTest | True | Asia | co-term | [] | URL
739153288842184492 | anv | True | Asia | co-term | [] | URL
646829496481090432 | IRI-BT-ORG | False | North America | co-term | [] | URL
646829496481090616 | Co-management test CW | False | North America | co-term | [] | URL
1030307 | Devnet-GroupDelta | True | Europe | co-term | [] | URL
1055430 | WARRAQ | False | North America | co-term | [] | URL
1057293 | meraki_test_reston | True | North America | per-device | [] | URL
1062199 | OPLK | False | North America | co-term | [] | URL
624311498344236932 | ericrod2 | True | North America | co-term | [] | URL
739153288842184053 | Nomios-NTA | False | Asia | co-term | [] | URL
739153288842183874 | Xmzx | True | Asia | per-device | [] | URL
646829496481089956 | Sam_Test | True | North America | co-term | [] | URL
646829496481090058 | RD networks | True | North America | co-term | [] | URL
646829496481090062 | Meraki-J | True | North America | co-term | [] | URL
646829496481090077 | CZ-TB-Test | True | North America | co-term | [] | URL
646829496481090100 | mh_test | True | North America | co-term | [] | URL
646829496481090148 | greger | True | North America | co-term | [] | URL
646829496481090153 | Sandbox Test | True | North America | co-term | [] | URL
646829496481090182 | GERIS | True | North America | per-device | [] | URL
646829496481090195 | TestFel | True | North America | co-term | [] | URL
646829496481090232 | Osho_branch | False | North America | co-term | [] | URL
646829496481090242 | Grossetofficet | True | North America | co-term | [] | URL
646829496481090243 | GTECH-ORG | True | North America | per-device | [] | URL
646829496481090303 | EWO | True | North America | co-term | [] | URL
646829496481090305 | SummerOrg | True | North America | co-term | [] | URL
646829496481090306 | WinterOrg | True | North America | co-term | [] | URL
646829496481090341 | SCCTest | True | North America | co-term | [] | URL
646829496481090413 | APItest | True | North America | co-term | [] | URL
646829496481090419 | devnetcoen | False | North America | co-term | [] | URL
646829496481090420 | devnetmeraki@cisco.com | True | North America | per-device | [] | URL
646829496481090424 | api_test | False | North America | co-term | [] | URL
646829496481090483 | elieorg | True | North America | co-term | [] | URL
646829496481090488 | preetan | False | North America | co-term | [] | URL
646829496481090489 | preetan | False | North America | co-term | [] | URL
646829496481090490 | preetan | False | North America | co-term | [] | URL
646829496481090537 | DomsOrg | False | North America | co-term | [] | URL
646829496481090548 | My organization | True | North America | co-term | [] | URL
646829496481090550 | MYORG | False | North America | co-term | [] | URL
646829496481090598 | Matheus | False | North America | co-term | [] | URL
646829496481090599 | Matheus-ORG | False | North America | co-term | [] | URL
646829496481090615 | TestCW | False | North America | co-term | [] | URL
646829496481090621 | TTD | False | North America | co-term | [] | URL
646829496481090886 | Artemis Organization | True | North America | co-term | [] | URL
646829496481090887 | ericrod2_v2 | True | North America | co-term | [] | URL
739153288842184055 | RoumiKasparrovka | True | Asia | co-term | [] | URL
739153288842183824 | Hello | False | Asia | co-term | [] | URL
739153288842183345 | HELLO_API | True | Asia | co-term | [] | URL
739153288842183770 | Stest | False | Asia | co-term | [] | URL
739153288842183875 | Magnet Masters | True | Asia | co-term | [] | URL
739153288842183178 | lukas | True | Asia | co-term | [] | URL
646829496481089711 | IPA | True | North America | co-term | [] | URL
739153288842183042 | PAOK | True | Asia | co-term | [] | URL
646829496481090891 | JoeBurrowFanClub | True | North America | co-term | [] | URL
739153288842184127 | Git-GroupOmicron2 | True | Asia | co-term | [] | URL
739153288842183030 | sampleNet | True | Asia | co-term | [] | URL
739153288842183605 | Chungus | True | Asia | co-term | [] | URL
739153288842183608 | Richard | True | Asia | co-term | [] | URL
739153288842184202 | Staging_Net | True | Asia | co-term | [] | URL
739153288842184064 | MyOrganizacionCuscoPeru | True | Asia | co-term | [] | URL
739153288842184203 | Staging_Net | True | Asia | co-term | [] | URL
739153288842184573 | Artemis Organization | True | Asia | co-term | [] | URL
739153288842183325 | Dxb_silicoon | True | Asia | co-term | [] | URL
739153288842184110 | Devnet-GroupBeta | True | Asia | co-term | [] | URL
739153288842184442 | CB Test | False | Asia | co-term | [] | URL
739153288842184137 | RoadRunner | True | Asia | co-term | [] | URL
739153288842182989 | Panenka Systems | True | Asia | co-term | [] | URL
739153288842184578 | Artemis Organization | True | Asia | co-term | [] | URL
739153288842183562 | XORGX | True | Asia | co-term | [] | URL
739153288842183617 | TestSD | True | Asia | co-term | [] | URL
739153288842184253 | Bodayngo | False | Asia | co-term | [] | URL
739153288842183131 | My_ORG | True | Asia | co-term | [] | URL
739153288842184114 | Diego-Test | True | Asia | co-term | [] | URL
739153288842183268 | MSP - Client A | True | Asia | co-term | [] | URL
739153288842184576 | Artemis Organization | True | Asia | co-term | [] | URL
739153288842184245 | NCH_TEST | True | Asia | co-term | [] | URL
739153288842183506 | SeaLab2020 | True | Asia | co-term | [] | URL
739153288842183144 | Charles Uneze Organization | True | Asia | co-term | [] | URL
739153288842183281 | my_new_test_meraki_org | True | Asia | co-term | [] | URL
739153288842184118 | Diego-Test3 | True | Asia | co-term | [] | URL
646829496481090277 | Cargill_lab | True | North America | co-term | [] | URL
739153288842184265 | MuthanaAPITest | False | Asia | co-term | [] | URL
646829496481090304 | Meraki_Ansible_Test | True | North America | co-term | [] | URL
646829496481090261 | SavTestOrganization | True | North America | co-term | [] | URL
646829496481090437 | BlueApple | True | North America | co-term | [] | URL
646829496481090622 | TTD_NETWORK | False | North America | co-term | [] | URL
646829496481090625 | TronsGreen | False | North America | co-term | [] | URL
549236 | DevNet Sandbox | True | North America | per-device | [] | URL
739153288842184201 | DevNet Sandbox | True | Asia | co-term | [] | URL
739153288842184348 | FT4_DallasWest | True | Asia | co-term | [] | URL
739153288842184715 | WSDOG | True | Asia | co-term | [] | URL
739153288842183771 | SuperNova | True | Asia | co-term | [] | URL
739153288842183142 | KB | True | Asia | per-device | [] | URL
739153288842184255 | My test organization | True | Asia | co-term | [] | URL
739153288842184256 | Phantom Technologies | True | Asia | co-term | [] | URL
739153288842184323 | VM_TDS_LAB | True | Asia | co-term | [] | URL
739153288842183222 | XYZ | True | Asia | co-term | [] | URL
739153288842183259 | FiveFold-Org | True | Asia | co-term | [] | URL
739153288842184015 | tomtest | True | Asia | co-term | [] | URL
739153288842183353 | ENAUTO | True | Asia | co-term | [] | URL
739153288842183777 | ducTran | True | Asia | co-term | [] | URL
739153288842184177 | DG | False | Asia | co-term | [] | URL
739153288842183652 | mc25 | True | Asia | co-term | [] | URL
739153288842183560 | DunderMifflin | True | Asia | co-term | [] | URL
739153288842183267 | Nath_Meraki | True | Asia | co-term | [] | URL
739153288842184122 | Devnet-GroupGamma | True | Asia | co-term | [] | URL
739153288842183338 | MaxOrganization | True | Asia | co-term | [] | URL
739153288842183649 | DevNetSandbox-J | True | Asia | per-device | [] | URL
739153288842183237 | Test_M_Org | True | Asia | co-term | [] | URL
739153288842183561 | DunderMifflinX | True | Asia | co-term | [] | URL
739153288842183386 | NTT LAB (EU) | True | Asia | co-term | [] | URL
739153288842182990 | My Enauto Org | True | Asia | per-device | [] | URL
739153288842184571 | HLT-XX-WAN-XXXX-NA-XX | True | Asia | co-term | [] | URL
739153288842183041 | Cali Unified | True | Asia | co-term | [] | URL
739153288842183233 | test01 | True | Asia | co-term | [] | URL
739153288842183346 | HELLO_API | True | Asia | co-term | [] | URL
739153288842183264 | SOCORP | True | Asia | co-term | [] | URL
739153288842184116 | Diego-Test3 | True | Asia | per-device | [] | URL
739153288842183911 | Niciu.com | False | Asia | co-term | [] | URL
739153288842184575 | Artemis Organization | True | Asia | co-term | [] | URL
739153288842183278 | my_new_test_meraki_org | True | Asia | co-term | [] | URL
739153288842183109 | Second Test Organization | True | Asia | co-term | [] | URL
739153288842183563 | EMEAR ORG | True | Asia | per-device | [] | URL
739153288842183876 | Magnetic Masters | True | Asia | co-term | [] | URL
739153288842183359 | ZAAZA | True | Asia | co-term | [] | URL
739153288842184254 | My test organization | True | Asia | co-term | [] | URL
739153288842183614 | Syrius_beta | True | Asia | co-term | [] | URL
739153288842184340 | MEZE | False | Asia | co-term | [] | URL
739153288842183519 | Prasad_testing | True | Asia | co-term | [] | URL
739153288842184113 | DevnetPrueba | True | Asia | co-term | [] | URL
739153288842183210 | MYLAND_2021 | True | Asia | co-term | [] | URL
739153288842183567 | JMK Org Test | True | Asia | co-term | [] | URL
739153288842183275 | Ragab | True | Asia | co-term | [] | URL
739153288842183112 | Org_1 | True | Asia | co-term | [] | URL
739153288842182996 | This is a test | True | Asia | co-term | [] | URL
739153288842182988 | My Enauto Org | True | Asia | co-term | [] | URL
739153288842184117 | Diego-Test3 | True | Asia | co-term | [] | URL
739153288842183833 | YAS-12345 | True | Asia | co-term | [] | URL
739153288842183873 | X_org | True | Asia | per-device | [] | URL
739153288842183895 | CISCOMERAKI | True | Asia | co-term | [] | URL